from setuptools import setup

setup(name='dimas_distributions',
      version='0.1',
      description='Gaussian distribution and Binomial Distributions',
      packages=['dimas_distributions'],
      author = 'Dimas Torres',
      zip_safe=False)
